@@ -1,19 +1,20 @@
 package Locale::CLDR::Locales::En::Any;
 
 # This file auto generated
-#	on Wed 10 Feb  7:58:37 am GMT
+#	on Sun  7 Oct 10:29:33 am GMT
 
 use version;
 
-our $VERSION = version->declare('v0.28.3');
+our $VERSION = version->declare('v0.33.1');
 
 use v5.10.1;
 use mro 'c3';
 use if $^V ge v5.12.0, feature => 'unicode_strings';
 
-use Moose;
+use Moo;
 
 extends('Locale::CLDR::Locales::En');
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
+no Moo;
+
+1;
